%define _requires_exceptions GLIBC_PRIVATE

#one of valgrind internal library is not linked to libc. Not sure if it should be fixed or not (since all test don't pass anyway), so disable check for now
%define _disable_ld_no_undefined 1

# disable debug package, it can prevent valgrind for working properly
%define debug_package   %{nil}

# (blino) FIXME: reenable qt4 as soon as availble in cauldron
%bcond_without	qt4

Name: 		valgrind
Version:	3.7.0
Release:	%mkrel 1
Summary: 	Memory debugger
License: 	GPLv2+
Group: 		Development/Other
Source0:	http://www.valgrind.org/downloads/%{name}-%{version}.tar.bz2
Patch1:		valgrind-3.7.0-cachegrind-improvements.patch
Patch2:		valgrind-3.7.0-openat.patch
Patch3:		valgrind-3.7.0-helgrind-race-supp.patch
Patch4:		valgrind-3.7.0-stat_h.patch
Patch5:		valgrind-3.7.0-capget.patch
Patch6:		valgrind-3.7.0-pie.patch
Patch7:		valgrind-3.7.0-gcc-version.patch
# Do not tell ebx is clobbered in exit syscall
# to avoid gcc error, as done in valgrind 3.6.1
Patch8:		valgrind-3.7.0-pic-clobber.patch
URL: 		http://valgrind.org/
ExclusiveArch:	%{ix86} x86_64 ppc
BuildRequires:	glibc-static-devel
BuildRequires:	gdb
# (proyvind): build with support for OpenMP, boost & qt4 threads
BuildRequires:	libgomp-devel boost-devel
%if %{with qt4}
BuildRequires:	qt4-devel
%endif
Suggests:	gdb
Obsoletes:	valgrind-plugins

%description
When a program is run under Valgrind's supervision, all reads and
writes of memory are checked, and calls to malloc/new/free/delete are
intercepted. As a result, Valgrind can detect problems such as:

    * Use of uninitialised memory
    * Reading/writing memory after it has been free'd
    * Reading/writing off the end of malloc'd blocks
    * Reading/writing inappropriate areas on the stack
    * Memory leaks -- where pointers to malloc'd blocks are lost forever
    * Passing of uninitialised and/or unaddressible memory to system calls
    * Mismatched use of malloc/new/new [] vs free/delete/delete []

%files
%defattr(-,root,root)
%doc README* AUTHORS FAQ.txt
%{_bindir}/*
%{_libdir}/%{name}
%{_mandir}/man1/*.1*

#--------------------------------------------------------------------

%package	devel
Summary:	%{summary}
Group:		%{group}
Conflicts:	%{name} < 3.6.1-3

%description	devel
Development files required to develop software using valgrind.

%files devel
%dir %{_includedir}/valgrind
%{_includedir}/valgrind/*
%{_libdir}/pkgconfig/%{name}.pc

#--------------------------------------------------------------------

%prep
%setup -q 
%apply_patches

%build
# rebuild uncododitionally because we patch configure.in
autoreconf
%configure2_5x

%make

%install
rm -rf %{buildroot}
# Don't strip (prevent valgrind from working properly, as explained in README_PACKAGERS)
export DONT_STRIP=1

# FIXME exporting DONT_STRIP=1 is causing some weird behavior with debug_package
# and causing it to not set DISABLE_DEBUG=1
export DISABLE_DEBUG=1
%makeinstall

#don't package generated files
rm -f $RPM_BUILD_ROOT%{_libdir}/valgrind/*.supp.in

%check
# Ensure there are no unexpected file descriptors open,
# the testsuite otherwise fails.
cat > close_fds.c <<EOF
#include <stdlib.h>
#include <unistd.h>
int main (int argc, char *const argv[])
{
  int i, j = sysconf (_SC_OPEN_MAX);
  if (j < 0)
    exit (1);
  for (i = 3; i < j; ++i)
    close (i);
  execvp (argv[1], argv + 1);
  exit (1);
}
EOF
gcc $RPM_OPT_FLAGS -o close_fds close_fds.c

for i in `find . -type f \( -name *-amd64-linux -o -name *-x86-linux -o -name *-ppc*-linux \)`; do
  case "`file $i`" in
    *ELF*executable*statically\ linked*)
      objcopy -R .debug_loc -R .debug_frame -R .debug_ranges $i
  esac
done

make check || :
# some tests are known to fail,
# just check no more tests are failing than Fedora ;)
echo ===============TESTING===================
# Cancel this temporarily because the tests hang on x86-64:
# http://thread.gmane.org/gmane.comp.debugging.valgrind/11792
# ./close_fds make regtest || :
echo ===============END TESTING===============



%clean
rm -rf %{buildroot}


%changelog

* Wed Dec 21 2011 shlomif <shlomif> 3.7.0-1.mga2
+ Revision: 185524
- Cancel make regtest because it hangs.

  + fwang <fwang>
    - sync with mandriva package

* Thu Oct 27 2011 shlomif <shlomif> 3.6.1-5.mga2
+ Revision: 158760
- Applied patches to build against kernel-3.x and glibc-2.14.x

* Wed Jun 22 2011 ahmad <ahmad> 3.6.1-4.mga2
+ Revision: 111971
- Add conflicts to ease updates after the -devel split (from tv)
- Re-enable building with qt4
- Only run autoreconf when building with qt4
- Drop unapplied patch3

* Tue Jun 07 2011 dmorgan <dmorgan> 3.6.1-3.mga2
+ Revision: 101519
- Provide devel subpackage  ( partial merge of mdv commit 659516)

* Sun May 15 2011 pterjan <pterjan> 3.6.1-2.mga1
+ Revision: 99037
- Rebuild for fixed find-requires

* Sat Apr 16 2011 pterjan <pterjan> 3.6.1-1.mga1
+ Revision: 86603
- Update to 3.6.1

* Tue Jan 11 2011 blino <blino> 3.6.0-2.mga1
+ Revision: 6503
- do not build with qt4 support for now
- remove versions in comments
- imported package valgrind


* Wed Nov 03 2010 Paulo Andrade <pcpa@mandriva.com.br> 3.6.0-1mdv2011.0
+ Revision: 593038
- Update to valgrind 3.6.0

  + Per Øyvind Karlsen <peroyvind@mandriva.org>
    - build with support for OpenMP, boost & qt4 threads

* Mon Dec 07 2009 Paulo Andrade <pcpa@mandriva.com.br> 3.5.0-2mdv2010.1
+ Revision: 474521
- Correct valgrind to work with glibc-2.11.

* Wed Aug 26 2009 Eugeni Dodonov <eugeni@mandriva.com> 3.5.0-1mdv2010.0
+ Revision: 421314
- updated to 3.5.0

* Thu Jun 25 2009 Per Øyvind Karlsen <peroyvind@mandriva.org> 3.4.1-3mdv2010.0
+ Revision: 389173
- add wildcards after GLIBC_VERSION to match any library micro versions as well (P4 from Fedora)
- redirect x86_64 ld.so strlen early (P3, RH bug #495645)

* Tue Jun 02 2009 Herton Ronaldo Krzesinski <herton@mandriva.com.br> 3.4.1-2mdv2010.0
+ Revision: 382232
- Rebuild with newer glibc (#51374).

* Thu Mar 05 2009 Frederic Crozat <fcrozat@mandriva.com> 3.4.1-1mdv2009.1
+ Revision: 348875
- Release 3.4.1
- Regenerate patch0
- Remove patch1 (merged upstream)

* Thu Jan 15 2009 Frederic Crozat <fcrozat@mandriva.com> 3.4.0-1mdv2009.1
+ Revision: 329847
- Release 3.4.0
- Remove patches 3, 8 (merged upstream)
- Regenerate patches 0 & 1

* Mon Jun 30 2008 Frederic Crozat <fcrozat@mandriva.com> 3.3.1-2mdv2009.0
+ Revision: 230240
- Update patch8 with upstream fix

* Thu Jun 26 2008 Frederic Crozat <fcrozat@mandriva.com> 3.3.1-1mdv2009.0
+ Revision: 229225
- Release 3.3.1
- Remove patches 4, 5, 6, 7 (merged upstream)
- Don't regenerate debug package, all debug info should stay in valgrind binaries

* Fri May 30 2008 Paulo Andrade <pcpa@mandriva.com.br> 3.3.0-5mdv2009.0
+ Revision: 213483
- Don't supress warnings only if the binary has been explicitly linked
  with libraries at /usr/X11*/lib*.

  + Frederic Crozat <fcrozat@mandriva.com>
    - Rebuild with glibc 4.3 / glibc 2.8
    - run make test in check section
    - Patch0 (Fedora): add cachegrind improvement
    - Patch1 (Fedora): fix pkgconfig file (RH bug #213149)
    - Patch2 (Fedora): fix openat handling (RH bug #208097)
    - Patch3 (Fedora): suppress pthread_barrier_wait in helgrind
    - Patch4 (Fedora): add suppression for glibc 2.7
    - Patch5 (Fedora): add support for glibc 2.8
    - Patches6, 7 (Fedora): add more syscalls
    - Patch8: fix malloc_free_fill test when glibc >= 2.7

* Thu Feb 21 2008 Adam Williamson <awilliamson@mandriva.org> 3.3.0-3mdv2008.1
+ Revision: 173469
- suggests gdb (#37755)

* Thu Feb 14 2008 Adam Williamson <awilliamson@mandriva.org> 3.3.0-2mdv2008.1
+ Revision: 167680
- new license policy
- drop bogus doc install hacks
- buildrequires gdb (#37739)
- spec clean
- drop Source1 (it's not actually used)

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

* Tue Dec 18 2007 trem <trem@mandriva.org> 3.3.0-1mdv2008.1
+ Revision: 131903
- update to 3.3.0
- remove patch for glibc-2.6

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Mon Aug 06 2007 Olivier Blin <oblin@mandriva.com> 3.2.3-2mdv2008.0
+ Revision: 59231
- use generic man page extension in files list (for lzma)
- add glibc-2.6 support (patch from Gentoo)


* Fri Mar 16 2007 Laurent Montel <lmontel@mandriva.com> 3.2.3-1mdv2007.1
+ Revision: 144737
- 3.2.3

* Sat Jan 13 2007 Michael Scherer <misc@mandriva.org> 3.2.1-1mdv2007.1
+ Revision: 108323
- update to 3.2.1, fix illegal instruction on current libstdc++ on x86_64
- Import valgrind

* Sat Jun 17 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.2.0-2mdv2007.0
- obsoletes valgrind-plugins

* Wed Jun 14 2006 Guillaume Rousse <guillomovitch@mandriva.org> 3.2.0-1mdv2007.0
- new version
- rpmbuildupdate aware
- spec cleanup
- move doc file in doc directory

* Sat Apr 29 2006 Jerome Soyer <saispo@mandriva.org> 3.1.1-1mdk
- New release 3.1.1

* Fri Feb 17 2006 Christiaan Welvaart <cjw@daneel.dyndns.org> 3.1.0-2mdk
- enable build for ppc

* Thu Dec 01 2005 Laurent MONTEL <lmontel@mandriva.com> 3.1.0-1mdk
- 3.1.0

* Tue Sep 06 2005 Gwenole Beauchesne <gbeauchesne@mandriva.com> 3.0.1-1mdk
- 3.0.1

* Fri Aug 05 2005 Laurent MONTEL <lmontel@mandriva.com> 3.0.0-1mdk
- 3.0.0

* Thu Mar 24 2005 Laurent MONTEL <lmontel@mandrakesoft.com> 2.4.0-1mdk
- 2.4.0

* Wed Jan 19 2005 Laurent MONTEL <lmontel@mandrakesoft.com> 2.2.0-2mdk
- Remove calltree from this package create new package valgrind-plugins and put callgrind into (because we can't compile callgrind without valgrind)

* Sat Sep 04 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.2.0-1mdk
- 2.2.0

* Thu Jul 22 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.2-1mdk
- 2.1.2 (see http://developer.kde.org/~sewardj/docs-2.0.0/NEWS.txt)

* Fri Apr 23 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.1-3mdk
- Add calltree plugins for kcachegrind (kdesdk)

* Tue Apr 20 2004 Per yvind Karlsen <peroyvind@linux-mandrake.com> 2.1.1-2mdk
- fix buildrequires
- use %%configure macro
- update url
- drop patches that wasn't applied

* Wed Mar 31 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.1-1mdk
- new version

* Wed Mar 31 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 2.1.0-3mdk
- Don't package twice manual.html bug #9314

